"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var babel_parser_1 = require("./babel-parser");
var cacher_1 = require("./utils/cacher");
var resolveExportedComponent_1 = require("./utils/resolveExportedComponent");
// tslint:disable-next-line:no-var-requires
var recast = require("recast");
var ERROR_MISSING_DEFINITION = 'No suitable component definition found';
function parseScript(source, documentation, handlers, options) {
    var plugins = options.lang === 'ts' ? ['typescript'] : ['flow'];
    var ast = cacher_1.default(function () { return recast.parse(source, { parser: babel_parser_1.default({ plugins: plugins }) }); }, source);
    if (!ast) {
        throw new Error(ERROR_MISSING_DEFINITION);
    }
    // FIXME: should be a Map<nameOfExport,NodePath>
    // then the documentation can become a map itself and we can look at component/mixins
    // with multiple items inside
    var componentDefinitions = resolveExportedComponent_1.default(ast);
    if (componentDefinitions.length === 0) {
        throw new Error(ERROR_MISSING_DEFINITION);
    }
    executeHandlers(handlers, componentDefinitions, documentation, ast, options.filePath);
}
exports.default = parseScript;
function executeHandlers(localHandlers, componentDefinitions, documentation, ast, filePath) {
    return componentDefinitions.forEach(function (compDef) {
        localHandlers.forEach(function (handler) { return handler(documentation, compDef, ast, filePath); });
    });
}
//# sourceMappingURL=parse-script.js.map