"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var bt = require("@babel/types");
var path = require("path");
var parse_1 = require("../parse");
var resolvePathFrom_1 = require("../utils/resolvePathFrom");
var resolveRequired_1 = require("../utils/resolveRequired");
/**
 * @returns {object} an object containing the documentations for each mixin
 * key: mixin variable name
 * value: documentation of named mixin
 */
function mixinsHandler(documentation, componentDefinition, astPath, originalFilePath) {
    var originalDirName = path.dirname(originalFilePath);
    // filter only mixins
    var mixinVariableNames = getMixinsVariableNames(componentDefinition);
    if (!mixinVariableNames) {
        return;
    }
    // get all require / import statements
    var mixinVarToFilePath = resolveRequired_1.default(astPath, mixinVariableNames);
    // get each doc for each mixin using parse
    for (var _i = 0, _a = Object.keys(mixinVarToFilePath); _i < _a.length; _i++) {
        var varName = _a[_i];
        var filePath = mixinVarToFilePath[varName];
        var fullFilePath = resolvePathFrom_1.default(filePath, originalDirName);
        parse_1.parseFile(fullFilePath, documentation);
    }
}
exports.default = mixinsHandler;
function getMixinsVariableNames(compDef) {
    if (!bt.isObjectExpression(compDef.node)) {
        return undefined;
    }
    var mixinProp = compDef
        .get('properties')
        .filter(function (p) { return p.node.key.name === 'mixins'; });
    var mixinPath = mixinProp.length ? mixinProp[0] : undefined;
    var varNames = [];
    if (mixinPath) {
        var mixinPropertyValue = mixinPath.node.value && bt.isArrayExpression(mixinPath.node.value)
            ? mixinPath.node.value.elements
            : [];
        mixinPropertyValue.forEach(function (e) {
            if (e && bt.isIdentifier(e)) {
                varNames.push(e.name);
            }
        });
    }
    return varNames;
}
//# sourceMappingURL=mixinsHandler.js.map